@@ -1,7 +1,7 @@
 """
 Type annotations for mediatailor service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/literals/)
 
 Usage::
 
@@ -41,6 +41,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -180,6 +181,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -386,3 +388,12 @@ PaginatorName = Literal[
     "list_source_locations",
     "list_vod_sources",
 ]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "eu-central-1",
+    "eu-west-1",
+    "us-east-1",
+    "us-west-2",
+]
