@@ -1,7 +1,7 @@
 """
 Type annotations for mediatailor service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/type_defs/)
 
 Usage::
 
@@ -81,6 +81,7 @@ __all__ = (
     "DescribeVodSourceResponseTypeDef",
     "GetChannelPolicyRequestRequestTypeDef",
     "GetChannelPolicyResponseTypeDef",
+    "GetChannelScheduleRequestGetChannelSchedulePaginateTypeDef",
     "GetChannelScheduleRequestRequestTypeDef",
     "GetChannelScheduleResponseTypeDef",
     "GetPlaybackConfigurationRequestRequestTypeDef",
@@ -91,18 +92,24 @@ __all__ = (
     "HlsPlaylistSettingsTypeDef",
     "HttpConfigurationTypeDef",
     "HttpPackageConfigurationTypeDef",
+    "ListAlertsRequestListAlertsPaginateTypeDef",
     "ListAlertsRequestRequestTypeDef",
     "ListAlertsResponseTypeDef",
+    "ListChannelsRequestListChannelsPaginateTypeDef",
     "ListChannelsRequestRequestTypeDef",
     "ListChannelsResponseTypeDef",
+    "ListPlaybackConfigurationsRequestListPlaybackConfigurationsPaginateTypeDef",
     "ListPlaybackConfigurationsRequestRequestTypeDef",
     "ListPlaybackConfigurationsResponseTypeDef",
+    "ListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef",
     "ListPrefetchSchedulesRequestRequestTypeDef",
     "ListPrefetchSchedulesResponseTypeDef",
+    "ListSourceLocationsRequestListSourceLocationsPaginateTypeDef",
     "ListSourceLocationsRequestRequestTypeDef",
     "ListSourceLocationsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "ListVodSourcesRequestListVodSourcesPaginateTypeDef",
     "ListVodSourcesRequestRequestTypeDef",
     "ListVodSourcesResponseTypeDef",
     "LivePreRollConfigurationTypeDef",
@@ -569,6 +576,15 @@ GetChannelPolicyResponseTypeDef = TypedDict(
     },
 )
 
+GetChannelScheduleRequestGetChannelSchedulePaginateTypeDef = TypedDict(
+    "GetChannelScheduleRequestGetChannelSchedulePaginateTypeDef",
+    {
+        "ChannelName": str,
+        "DurationMinutes": NotRequired[str],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 GetChannelScheduleRequestRequestTypeDef = TypedDict(
     "GetChannelScheduleRequestRequestTypeDef",
     {
@@ -672,6 +688,14 @@ HttpPackageConfigurationTypeDef = TypedDict(
     },
 )
 
+ListAlertsRequestListAlertsPaginateTypeDef = TypedDict(
+    "ListAlertsRequestListAlertsPaginateTypeDef",
+    {
+        "ResourceArn": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListAlertsRequestRequestTypeDef = TypedDict(
     "ListAlertsRequestRequestTypeDef",
     {
@@ -690,6 +714,13 @@ ListAlertsResponseTypeDef = TypedDict(
     },
 )
 
+ListChannelsRequestListChannelsPaginateTypeDef = TypedDict(
+    "ListChannelsRequestListChannelsPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListChannelsRequestRequestTypeDef = TypedDict(
     "ListChannelsRequestRequestTypeDef",
     {
@@ -707,6 +738,13 @@ ListChannelsResponseTypeDef = TypedDict(
     },
 )
 
+ListPlaybackConfigurationsRequestListPlaybackConfigurationsPaginateTypeDef = TypedDict(
+    "ListPlaybackConfigurationsRequestListPlaybackConfigurationsPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListPlaybackConfigurationsRequestRequestTypeDef = TypedDict(
     "ListPlaybackConfigurationsRequestRequestTypeDef",
     {
@@ -724,6 +762,15 @@ ListPlaybackConfigurationsResponseTypeDef = TypedDict(
     },
 )
 
+ListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef = TypedDict(
+    "ListPrefetchSchedulesRequestListPrefetchSchedulesPaginateTypeDef",
+    {
+        "PlaybackConfigurationName": str,
+        "StreamId": NotRequired[str],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListPrefetchSchedulesRequestRequestTypeDef = TypedDict(
     "ListPrefetchSchedulesRequestRequestTypeDef",
     {
@@ -743,6 +790,13 @@ ListPrefetchSchedulesResponseTypeDef = TypedDict(
     },
 )
 
+ListSourceLocationsRequestListSourceLocationsPaginateTypeDef = TypedDict(
+    "ListSourceLocationsRequestListSourceLocationsPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListSourceLocationsRequestRequestTypeDef = TypedDict(
     "ListSourceLocationsRequestRequestTypeDef",
     {
@@ -775,6 +829,14 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
+ListVodSourcesRequestListVodSourcesPaginateTypeDef = TypedDict(
+    "ListVodSourcesRequestListVodSourcesPaginateTypeDef",
+    {
+        "SourceLocationName": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListVodSourcesRequestRequestTypeDef = TypedDict(
     "ListVodSourcesRequestRequestTypeDef",
     {
